@@ -4,7 +4,7 @@ General action base class with automation for hot loading
 from importlib.util import spec_from_file_location, module_from_spec
 from jaseci.utils.utils import logger
 from jaseci.actions.remote_actions import ACTIONS_SPEC_LOC
-from jaseci.actions.remote_actions import serv_actions, mark_as_remote
+from jaseci.actions.remote_actions import serv_actions, mark_as_remote, mark_as_endpoint
 import requests
 import os
 import sys
@@ -30,6 +30,21 @@ def jaseci_action(act_group=None, aliases=list(), allow_remote=False):
     return decorator_func
 
 
+def jaseci_expose(endpoint, mount=None):
+    """Decorator for Jaseci Action interface"""
+    caller_globals = dict(inspect.getmembers(inspect.currentframe().f_back))[
+        "f_globals"
+    ]
+    if "serv_actions" not in caller_globals:
+        caller_globals["serv_actions"] = serv_actions
+
+    def decorator_func(func):
+        mark_as_endpoint([func, endpoint, mount, caller_globals])
+        return func
+
+    return decorator_func
+
+
 def assimilate_action(func, act_group=None, aliases=list()):
     """Helper for jaseci_action decorator"""
     act_group = [func.__module__.split(".")[-1]] if act_group is None else act_group
