@@ -1,5 +1,4 @@
-rand_std = \
-    """
+rand_std = """
     walker init
     {
         report rand.word();
@@ -9,8 +8,7 @@ rand_std = \
     }
     """
 
-file_io = \
-    """
+file_io = """
     walker init {
         fn="fileiotest.txt";
         a = {'a': 5};
@@ -22,11 +20,11 @@ file_io = \
         file.append_str(fn, c);
         c=file.load_str(fn);
         report c;
+        file.delete(fn);
     }
     """
 
-std_used_in_node_has_var = \
-    """
+std_used_in_node_has_var = """
     node testnode {has a=rand.sentence();}
 
     walker init
