@@ -108,6 +108,21 @@ class GraphApi:
                 ret[i] = nd_ctx[i]
         return ret
 
+    @Interface.private_api(cli_args=["nd"])
+    def graph_node_view(
+        self, nd: Node = None, detailed: bool = False, show_edges: bool = True
+    ):
+        """
+        Returns value a given node
+        """
+        ret = [nd.serialize(detailed=detailed)]
+        if show_edges:
+            for i in nd.attached_edges():
+                ret.append(i.serialize(detailed=detailed))
+        for i in nd.attached_nodes():
+            ret.append(i.serialize(detailed=detailed))
+        return ret
+
     @Interface.private_api(cli_args=["nd"])
     def graph_node_set(self, nd: Node, ctx: dict, snt: Sentinel = None):
         """
