@@ -14,8 +14,8 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def setUp(self):
         super().setUp()
-        self.gph = Graph(m_id="anon", h=MetaService().hook())
-        self.sent = Sentinel(m_id=self.gph._m_id, h=self.gph._h)
+        self.sent = Sentinel(m_id="anon", h=MetaService().hook())
+        self.gph = Graph(m_id="anon", h=self.sent._h)
         self.old_stdout = sys.stdout
         self.new_stdout = io.StringIO()
         sys.stdout = self.new_stdout
@@ -31,21 +31,21 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_basic_arith(self):
         self.sent.register_code(jtc.basic_arith)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "8 -20 1.0 -2 -13.0\n")
 
     def test_additional_arith(self):
         self.sent.register_code(jtc.more_arith)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "256 4\n")
 
     def test_compare(self):
         self.sent.register_code(jtc.compare)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -54,7 +54,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_logical(self):
         self.sent.register_code(jtc.logical)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -63,35 +63,35 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_assignments(self):
         self.sent.register_code(jtc.assignments)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "8\n16\n36\n36.0\n-18.0\n")
 
     def test_if_stmt(self):
         self.sent.register_code(jtc.if_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "Hello!\n")
 
     def test_else_stmt(self):
         self.sent.register_code(jtc.else_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "A is not equal to B\n")
 
     def test_elif_stmt(self):
         self.sent.register_code(jtc.elif_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "A is one less than B\n")
 
     def test_for_stmt(self):
         self.sent.register_code(jtc.for_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -104,7 +104,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_while_stmt(self):
         self.sent.register_code(jtc.while_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -115,7 +115,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_break_stmt(self):
         self.sent.register_code(jtc.break_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -127,7 +127,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_continue_stmt(self):
         self.sent.register_code(jtc.continue_stmt)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -137,7 +137,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_continue_stmt2(self):
         self.sent.register_code(jtc.continue_stmt2)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -147,7 +147,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_destroy_disconnect(self):
         self.sent.register_code(jtc.destroy_disconn)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         out = self.new_stdout.getvalue()
@@ -155,7 +155,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_array_assign(self):
         self.sent.register_code(jtc.array_assign)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -168,7 +168,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_md_array_assign(self):
         self.sent.register_code(jtc.array_md_assign)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -177,35 +177,35 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_dereference(self):
         self.sent.register_code(jtc.dereference)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue()[:9], "urn:uuid:")
 
     def test_pre_post_walk(self):
         self.sent.register_code(jtc.pre_post_walking)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "count: 8\n")
 
     def test_pre_post_walk_disengage(self):
         self.sent.register_code(jtc.pre_post_walking_dis)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "count: 6\n")
 
     def test_length(self):
         self.sent.register_code(jtc.length)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "3\n3\n")
 
     def test_sort_by_col(self):
         self.sent.register_code(jtc.sort_by_col)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -219,7 +219,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_list_remove_element(self):
         self.sent.register_code(jtc.list_remove)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -230,14 +230,14 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_can_action(self):
         self.sent.register_code(jtc.can_action)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "56 7\n" "56 8\n")
 
     def test_can_action_param(self):
         self.sent.register_code(jtc.can_action_params)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -246,7 +246,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_cross_scope_report(self):
         self.sent.register_code(jtc.cross_scope_report)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertIn(56, gen_walker.report)
@@ -255,24 +255,22 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_has_private(self):
         self.sent.register_code(jtc.has_private)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         print(gen_walker.report)
-        self.assertTrue(
-            self.new_stdout.getvalue().startswith("[{'context': {'apple': 12,")
-        )
+        self.assertIn("'context': {'apple': 12, 'grape': 1", self.new_stdout.getvalue())
 
     def test_array_idx_of_expr(self):
         self.sent.register_code(jtc.array_idx_of_expr)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(self.new_stdout.getvalue(), "3\n1\n")
 
     def test_dict_assign(self):
         self.sent.register_code(jtc.dict_assign)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -284,7 +282,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_dict_md_assign(self):
         self.sent.register_code(jtc.dict_md_assign)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -294,7 +292,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_dict_keys(self):
         self.sent.register_code(jtc.dict_keys)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -304,7 +302,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_cond_dict_keys(self):
         self.sent.register_code(jtc.cond_dict_keys)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -314,7 +312,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_vector_softmax(self):
         self.sent.register_code(jtc.soft_max)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -324,7 +322,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_book_fam_example(self):
         self.sent.register_code(jtc.fam_example)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("create_fam")
+        gen_walker = self.sent.run_architype("create_fam")
         gen_walker.prime(self.gph)
         gen_walker.run()
         self.assertEqual(
@@ -333,7 +331,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_book_visitor_preset(self):
         self.sent.register_code(jtc.visitor_preset)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         outsplit = self.new_stdout.getvalue().split("\n")
@@ -347,7 +345,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_book_visitor_local_aciton(self):
         self.sent.register_code(jtc.visitor_local_aciton)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         outsplit = self.new_stdout.getvalue().split("\n")
@@ -359,7 +357,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def test_book_copy_assign_to_edge(self):
         self.sent.register_code(jtc.copy_assign_to_edge)
-        gen_walker = self.sent.walker_ids.get_obj_by_name("init")
+        gen_walker = self.sent.run_architype("init")
         gen_walker.prime(self.gph)
         gen_walker.run()
         outsplit = self.new_stdout.getvalue().split("\n")
