@@ -34,30 +34,24 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_jac_code(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog1)
-        self.assertIsNotNone(sent.walker_ids.get_obj_by_name("get_gen_day"))
+        self.assertIsNotNone(sent.run_architype("get_gen_day"))
         self.assertIsNotNone(sent.arch_ids.get_obj_by_name("week", kind="node"))
 
     def test_sentinel_loading_jac_code_multiple_times(self):
         """Test registering resets correctly for multiple attempts"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog0)
-        num_walkers = len(sent.walker_ids)
         num_arch = len(sent.arch_ids)
         sent.register_code(jtc.prog0)
-        self.assertEqual(len(sent.walker_ids), num_walkers)
         self.assertEqual(len(sent.arch_ids), num_arch)
         sent.register_code(jtc.prog0)
-        self.assertEqual(len(sent.walker_ids), num_walkers)
         self.assertEqual(len(sent.arch_ids), num_arch)
 
     def test_sentinel_register_dep_on_static_errors(self):
         """Test Jac registering is dependant on correct static/dynamic code"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         correct = "node b { has anchor a; }"
         wrong1 = "adfdsf"
         sent.register_code(correct)
@@ -73,8 +67,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_arhitype(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog1)
         self.assertGreater(
             len(sent.arch_ids.get_obj_by_name("month", kind="node").code_ir), 5
@@ -82,11 +75,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_running_basic_walker(self):
         """Test the execution of a basic walker building graph"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
-        test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
+        test_walker = sent.run_architype("get_gen_day")
         test_walker.prime(test_node)
         test_walker.context["date"] = "2010-08-03T03:00:00.000000"
         test_walker.run()
@@ -99,11 +91,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_setp_running_walker(self):
         """Test the execution of a basic walker building graph"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
-        test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
+        test_walker = sent.run_architype("get_gen_day")
         test_walker.prime(test_node)
         test_walker.context["date"] = "2010-08-03T03:00:00.000000"
         self.assertEqual(len(test_node.outbound_nodes()), 0)
@@ -123,11 +114,11 @@ class JacTests(TestCaseHelper, TestCase):
         """
         Test that  no loss or gain of data on second trak on second trek
         """
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
-        test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
+        test_walker = sent.run_architype("get_gen_day")
         test_walker.prime(test_node)
         test_walker.context["date"] = "2010-08-03T03:00:00.000000"
         self.assertEqual(test_walker.context["date"], "2010-08-03T03:00:00.000000")
@@ -146,11 +137,10 @@ class JacTests(TestCaseHelper, TestCase):
         scalably (node contexts dont get deleted when arch_ids deleted)
         """
         lact.load_local_actions(os.path.dirname(__file__) + "/infer.py")
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
-        test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
+        test_walker = sent.run_architype("get_gen_day")
         test_walker.prime(test_node)
         test_walker.context["date"] = "2010-08-03T03:00:00.000000"
         self.assertEqual(test_walker.context["date"], "2010-08-03T03:00:00.000000")
@@ -164,11 +154,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sent_loads_complex_walker_and_arch(self):
         """Test loading attributes of arch and walkers"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("testnode", kind="node").run()
-        test_walker = sent.walker_ids.get_obj_by_name("testwalk")
+        test_walker = sent.run_architype("testwalk")
         test_walker.prime(test_node)
         test_walker.run()
         self.assertEqual(test_node.context["c"], '43Yeah \n"fools"!')
@@ -179,10 +168,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_work(self):
         """Test that multiple edges between the same two nodes are allowed"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -194,10 +183,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey2)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -205,10 +194,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_specific(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey2b)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -216,10 +205,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_labeled(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey2c)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -227,10 +216,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_filtered(self):
         """Test that multiple edges deleted correctly if delete filtered"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey3)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -238,10 +227,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_generic_can_be_used_to_specify_generic_edges(self):
         """Test that generic edge tag works"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey4)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -249,10 +238,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_simultaneously(self):
         """Test disconnecting mutilpe nodes"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey5)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -260,10 +249,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_can_connect_multi_nodes_simultaneously(self):
         """Test connecting mutilpe nodes"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey6)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -271,10 +260,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_advanced(self):
         """Test disconnecting mutilpe nodes advanced"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey7)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -282,10 +271,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_accessing_edges_basic(self):
         """Test accessing Edges"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edge_access)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         edges = gph.get_all_edges()
@@ -298,10 +287,10 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_has_assign(self):
         """Test assignment on definition"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.has_assign)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         nodes = gph.get_all_nodes()
@@ -316,13 +305,13 @@ class JacTests(TestCaseHelper, TestCase):
     def test_global_get_set(self):
         """Test assignment on definition"""
         mast = self.meta.super_master()
+        sent = Sentinel(m_id=mast.jid, h=mast._h)
         gph = Graph(m_id=mast.jid, h=mast._h)
-        sent = Sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.set_get_global)
-        test_walker = sent.walker_ids.get_obj_by_name("setter")
+        test_walker = sent.run_architype("setter")
         test_walker.prime(gph)
         test_walker.run()
-        test_walker2 = sent.walker_ids.get_obj_by_name("getter")
+        test_walker2 = sent.run_architype("getter")
         test_walker2.prime(gph)
         test_walker2.run()
         self.assertEqual(test_walker2.context["a"], 59)
@@ -330,13 +319,13 @@ class JacTests(TestCaseHelper, TestCase):
     def test_global_set_requires_admin(self):
         """Test assignment on definition"""
         mast = self.meta.master()
+        sent = Sentinel(m_id=mast.jid, h=mast._h)
         gph = Graph(m_id=mast.jid, h=mast._h)
-        sent = Sentinel(m_id=mast.jid, h=gph._h)
-        sent.register_code(jtc.set_get_global)
-        test_walker = sent.walker_ids.get_obj_by_name("setter")
+        sent.register_code(jtc.set_get_global2)
+        test_walker = sent.run_architype("setter")
         test_walker.prime(gph)
         test_walker.run()
-        test_walker2 = sent.walker_ids.get_obj_by_name("getter")
+        test_walker2 = sent.run_architype("getter")
         test_walker2.prime(gph)
         test_walker2.run()
         self.assertEqual(test_walker2.context["a"], None)
@@ -344,30 +333,29 @@ class JacTests(TestCaseHelper, TestCase):
     def test_sentinel_version_label(self):
         """Test sentinel version labeling"""
         mast = self.meta.master()
-        gph = Graph(m_id=mast.jid, h=mast._h)
-        sent = Sentinel(m_id=mast.jid, h=gph._h)
+        sent = Sentinel(m_id=mast.jid, h=mast._h)
         sent.register_code(jtc.version_label)
         self.assertEqual(sent.version, "alpha-1.0")
 
     def test_visibility_builtins(self):
         """Test builtins to see into nodes and edges"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.visibility_builtins)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual(2, len(test_walker.report[0][0].keys()))
-        self.assertGreaterEqual(len(test_walker.report[0][1].keys()), 7)
+        self.assertGreaterEqual(len(test_walker.report[0][1].keys()), 6)
         self.assertLess(len(test_walker.report[0][1].keys()), 14)
-        self.assertGreaterEqual(len(test_walker.report[0][2].keys()), 14)
+        self.assertGreaterEqual(len(test_walker.report[0][2].keys()), 13)
 
     def test_spawn_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.spawn_ctx_edge_node)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual(test_walker.report[0]["age"], 32)
@@ -377,20 +365,20 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_filter_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.filter_ctx_edge_node)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual(test_walker.report[0]["age"], 30)
         self.assertEqual(len(test_walker.report[1]), 0)
 
     def test_null_handling(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.null_handleing)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual(test_walker.report[0], True)
@@ -399,20 +387,20 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[3], False)
 
     def test_bool_type_convert(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.bool_type_convert)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual(test_walker.report[0], True)
         self.assertEqual(True, test_walker.report[1]["name"])
 
     def test_typecasts(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.typecasts)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual(test_walker.report[0], 7.6)
@@ -423,10 +411,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[5], "Types comes back correct")
 
     def test_typecast_error(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.typecasts_error)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertIn("Cannot get edges from 7.6", test_walker.runtime_errors[0])
@@ -436,10 +424,10 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_filter_on_context(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.filter_on_context)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertEqual({"yo": "Yeah i said"}, test_walker.report[0][0])
@@ -447,10 +435,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("name", test_walker.report[0][2].keys())
 
     def test_string_manipulation(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.string_manipulation)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -486,10 +474,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[29], True)
 
     def test_list_manipulation(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.list_manipulation)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -506,10 +494,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[10], [])
 
     def test_list_reversed(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.list_reversed)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -517,10 +505,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[1], [4, 2, 7])
 
     def test_dict_manipulation(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.dict_manipulation)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -534,20 +522,20 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[7], {})
 
     def test_string_join(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.string_join)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
         self.assertEqual(rep[0], "test_me_now")
 
     def test_sub_list(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.sub_list)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -556,10 +544,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0][2], 7)
 
     def test_destroy_and_misc(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.destroy_and_misc)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -581,10 +569,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[9], True)
 
     def test_arbitrary_assign_on_element(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.arbitrary_assign_on_element)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -593,10 +581,10 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_try_else_stmts(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.try_else_stmts)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -618,10 +606,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[3], 2)
 
     def test_node_edge_same_name(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.node_edge_same_name)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -631,8 +619,7 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_testcases(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.testcases)
         sent.run_tests(silent=True)
         self.assertEqual(len(sent.testcases), 4)
@@ -640,8 +627,7 @@ class JacTests(TestCaseHelper, TestCase):
             self.assertEqual(i["passed"], True)
 
     def test_testcase_asserts(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
         sent.register_code(jtc.testcase_asserts)
         sent.run_tests(silent=True)
         self.assertEqual(len(sent.testcases), 3)
@@ -650,10 +636,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(sent.testcases[2]["passed"], False)
 
     def test_report_not_to_jacset(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.report_not_to_jacset)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
@@ -661,40 +647,40 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("j_type", rep[0][0].keys())
 
     def test_walker_spawn_unwrap_check(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.walker_spawn_unwrap_check)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
         self.assertTrue(rep[0].startswith("urn:uuid"))
 
     def test_std_get_report(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.std_get_report)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
         self.assertEqual(rep, [3, 5, 6, 7, [3, 5, 6, 7], 8])
 
     def test_func_with_array_index(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.func_with_array_index)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         rep = test_walker.report
         self.assertEqual(rep, [3, 5, 3])
 
     def test_rt_error_test1(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.rt_error_test1)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         self.assertIn("List index out of range", test_walker.runtime_errors[0])
@@ -702,40 +688,40 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn(" col ", test_walker.runtime_errors[0])
 
     def test_root_type_nodes(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.root_type_nodes)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
         self.assertEqual(report, ["root", "root"])
 
     def test_invalid_key_error(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.invalid_key_error)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         errors = test_walker.runtime_errors
         self.assertGreater(len(errors), 0)
 
     def test_auto_cast(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.auto_cast)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
         self.assertEqual(report, [True, True])
 
     def test_no_error_on_dict_key_assign(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.no_error_on_dict_key_assign)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
@@ -743,10 +729,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.runtime_errors), 0)
 
     def test_report_status(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.report_status)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
@@ -754,40 +740,40 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report_status, 302)
 
     def test_graph_in_graph(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.graph_in_graph)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
         self.assertEqual(len(report), 3)
 
     def test_min_max_on_list(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.min_max_on_list)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
         self.assertEqual(report, [531.1, 3, 5, 1])
 
     def test_edge_bug(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edge_bug)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
         self.assertEqual(len(report[0]), 4)
 
     def test_rand_choice(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.rand_choice)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
