@@ -1,28 +1,29 @@
-from jaseci.svcs.meta_svc import meta_svc
-from jaseci.utils.utils import TestCaseHelper
 from unittest import TestCase
-from jaseci.graph.node import node
+
+from jaseci.actor.architype import Architype
 from jaseci.attr import action
-from jaseci.graph.edge import edge
-from jaseci.actor.architype import architype
+from jaseci.graph.edge import Edge
+from jaseci.graph.node import Node
+from jaseci.svc import MetaService
+from jaseci.utils.utils import TestCaseHelper
 
 
-class node_tests(TestCaseHelper, TestCase):
+class NodeTests(TestCaseHelper, TestCase):
     """Tests for the funcationality of Jaseci node class"""
 
     def setUp(self):
         super().setUp()
-        self.meta = meta_svc()
+        self.meta = MetaService()
 
     def tearDown(self):
         super().tearDown()
 
     def test_node_connections(self):
         """Test connecting and disconnecting etc of nodes"""
-        node1 = node(m_id="anon", h=self.meta.hook())
-        node2 = node(m_id="anon", h=node1._h)
-        node3 = node(m_id="anon", h=node1._h)
-        node4 = node(m_id="anon", h=node1._h)
+        node1 = Node(m_id="anon", h=self.meta.hook())
+        node2 = Node(m_id="anon", h=node1._h)
+        node3 = Node(m_id="anon", h=node1._h)
+        node4 = Node(m_id="anon", h=node1._h)
         node1.attach_outbound(node2)
         node3.attach_outbound(node2)
         node1.attach_inbound(node2)
@@ -48,7 +49,7 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_add_context_to_node_and_destroy(self):
         """Test adding and removing contexts nodes"""
-        node1 = node(m_id="anon", h=self.meta.hook())
+        node1 = Node(m_id="anon", h=self.meta.hook())
         node1.context["yeah dude"] = "SUP"
         self.assertEqual(node1.context["yeah dude"], "SUP")
         self.assertEqual(len(node1.context.keys()), 1)
@@ -57,8 +58,8 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_add_entry_action_to_node_and_destroy(self):
         """Test connecting and disconnecting etc of nodes"""
-        node1 = architype(m_id="anon", h=self.meta.hook())
-        act = action.action(m_id="anon", h=node1._h, name="yeah dude", value="SUP")
+        node1 = Architype(m_id="anon", h=self.meta.hook())
+        act = action.Action(m_id="anon", h=node1._h, name="yeah dude", value="SUP")
         node1.entry_action_ids.add_obj(act)
         self.assertEqual(
             node1.entry_action_ids.get_obj_by_name("yeah dude").value, "SUP"
@@ -73,13 +74,13 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_adding_and_removing_from_hdnodes(self):
         """Test adding nodes and removing them from HDGDs"""
-        node1 = node(m_id="anon", h=self.meta.hook())
-        hdgd1 = node(m_id="anon", h=node1._h, name="yeah dude", dimension=1)
+        node1 = Node(m_id="anon", h=self.meta.hook())
+        hdgd1 = Node(m_id="anon", h=node1._h, name="yeah dude", dimension=1)
         node1.make_member_of(hdgd1)
         self.assertEqual(node1.parent_node_ids.obj_list()[0], hdgd1)
         self.assertEqual(hdgd1.member_node_ids.obj_list()[0], node1)
 
-        hdgd2 = node(m_id="anon", h=node1._h, dimension=2)
+        hdgd2 = Node(m_id="anon", h=node1._h, dimension=2)
         node1.make_member_of(hdgd2)
         self.assertNotIn(hdgd2.id, node1.parent_node_ids)
 
@@ -88,19 +89,19 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_dimensions_must_match_to_connect_nodes(self):
         """Test dimension matching requirement for node connection"""
-        node1 = node(m_id="anon", h=self.meta.hook())
-        hdgd1 = node(m_id="anon", h=node1._h, name="yeah dude", dimension=1)
+        node1 = Node(m_id="anon", h=self.meta.hook())
+        hdgd1 = Node(m_id="anon", h=node1._h, name="yeah dude", dimension=1)
         node1.attach_outbound(hdgd1)
         self.assertFalse(node1.is_attached_out(hdgd1))
 
     def test_inherit_from_element_edge(self):
         """Test that inheriting params with kwargs works"""
         hook = self.meta.hook()
-        a = edge(
+        a = Edge(
             name="my edge",
             m_id="anon",
             h=hook,
-            to_node=node(m_id="anon", h=hook),
-            from_node=node(m_id="anon", h=hook),
+            to_node=Node(m_id="anon", h=hook),
+            from_node=Node(m_id="anon", h=hook),
         )
         self.assertEqual(a.name, "my edge")
