@@ -20,10 +20,10 @@ class JacTests(TestCaseHelper, TestCase):
         super().tearDown()
 
     def test_bug_check1(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtp.bug_check1)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
@@ -47,10 +47,10 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report[0], False)
 
     def test_globals(self):
-        gph = Graph(m_id="anon", h=self.meta.hook())
-        sent = Sentinel(m_id="anon", h=gph._h)
+        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtp.globals)
-        test_walker = sent.walker_ids.get_obj_by_name("init")
+        test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
         report = test_walker.report
@@ -214,7 +214,6 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("j_r_acc_ids", report[0][0].keys())
 
     def test_jasecilib_create_user(self):
-        self.logger_on()
         mast = self.meta.master()
         mast.sentinel_register(name="test", code=jtp.jasecilib_create_user, auto_run="")
         report = mast.general_interface_to_api(
